@@ -40,16 +40,22 @@ void TableDialog::on_createTableWidget_itemSelectionChanged() {
     */
 
     updateMaxItems();
+    const QList<QTableWidgetSelectionRange> &list =
+        ui->createTableWidget->selectedRanges();
+
+    if (list.isEmpty()) {
+        return;
+    }
+
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
-    QTableWidgetSelectionRange range =
-        ui->createTableWidget->selectedRanges().constFirst();
+    QTableWidgetSelectionRange range = list.constFirst();
 #else
     QTableWidgetSelectionRange range =
-        ui->createTableWidget->selectedRanges().first();
+        list.first();
 #endif
 
-    ui->rowSpinBox->setValue(std::max(_maxRows, range.rowCount()));
-    ui->columnSpinBox->setValue(std::max(_maxColumns, range.columnCount()));
+    ui->rowSpinBox->setValue(std::max<int>(_maxRows, range.rowCount()));
+    ui->columnSpinBox->setValue(std::max<int>(_maxColumns, range.columnCount()));
 }
 
 void TableDialog::updateMaxItems() {
@@ -59,8 +65,8 @@ void TableDialog::updateMaxItems() {
             bool hasText = item != nullptr ? !item->text().isEmpty() : false;
 
             if (hasText) {
-                _maxRows = std::max(_maxRows, row + 1);
-                _maxColumns = std::max(_maxColumns, col + 1);
+                _maxRows = std::max<int>(_maxRows, row + 1);
+                _maxColumns = std::max<int>(_maxColumns, col + 1);
             }
         }
     }
