@@ -39,6 +39,18 @@ class QOwnNotesMarkdownHighlighter : public MarkdownHighlighter {
 
     void updateCurrentNote(Note *note);
 
+    struct ScriptingHighlightingRule {
+        explicit ScriptingHighlightingRule(const HighlighterState state_)
+            : state(state_) {}
+        ScriptingHighlightingRule() = default;
+
+        QRegularExpression pattern;
+        QString shouldContain;
+        HighlighterState state = NoState;
+        uint8_t capturingGroup = 0;
+        uint8_t maskedGroup = 0;
+    };
+
    protected:
     void highlightBlock(const QString &text) Q_DECL_OVERRIDE;
 
@@ -57,4 +69,6 @@ class QOwnNotesMarkdownHighlighter : public MarkdownHighlighter {
     QString _defaultNoteFileExt;
     QRegularExpression _regexTagStyleLink;
     QRegularExpression _regexBracketLink;
+    void highlightScriptingRules(const QVector<ScriptingHighlightingRule> &rules,
+                                 const QString &text);
 };
