@@ -33,6 +33,7 @@ class QPlainTextEditSearchWidget : public QWidget {
                   bool updateUI = true);
     void setDarkMode(bool enabled);
     ~QPlainTextEditSearchWidget();
+
     void setSearchText(const QString &searchText);
     void setSearchMode(SearchMode searchMode);
     void setDebounceDelay(uint debounceDelay);
@@ -54,9 +55,9 @@ class QPlainTextEditSearchWidget : public QWidget {
    protected:
     QPlainTextEdit *_textEdit;
     bool _darkMode;
-    bool eventFilter(QObject *obj, QEvent *event);
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
-   public slots:
+   public Q_SLOTS:
     void activate();
     void deactivate();
     void doSearchDown();
@@ -68,12 +69,12 @@ class QPlainTextEditSearchWidget : public QWidget {
     void reset();
     void doSearchCount();
 
-   protected slots:
+   protected Q_SLOTS:
     void searchLineEditTextChanged(const QString &arg1);
     void performSearch();
     void updateSearchCountLabelText();
     void setSearchSelectionColor(const QColor &color);
-   private slots:
+   private Q_SLOTS:
     void on_modeComboBox_currentIndexChanged(int index);
     void on_matchCaseSensitiveButton_toggled(bool checked);
 };
