@@ -20,31 +20,15 @@
 #include <QTextBlock>
 #include <QTextDocument>
 #include <QTreeWidgetItem>
-#include <QtConcurrent/QtConcurrent>
 
 NavigationWidget::NavigationWidget(QWidget *parent)
-    : QTreeWidget(parent), _document(nullptr) {
+    : QTreeWidget(parent) {
     // we want to handle currentItemChanged because it also works with the keyboard
     QObject::connect(this, &NavigationWidget::currentItemChanged, this,
                      &NavigationWidget::onCurrentItemChanged);
     // we want to handle itemClicked because it allows to click on an item a 2nd time
     QObject::connect(this, &NavigationWidget::itemClicked, this,
                      &NavigationWidget::onItemClicked);
-
-    _parseFutureWatcher = new QFutureWatcher<QVector<Node>>(this);
-    connect(_parseFutureWatcher, &QFutureWatcher<QVector<Node>>::finished, this,
-            &NavigationWidget::onParseCompleted);
-}
-
-NavigationWidget::~NavigationWidget() {
-    this->_parseFutureWatcher->waitForFinished();
-}
-
-/**
- * Sets a document to parse
- */
-void NavigationWidget::setDocument(const QTextDocument *document) {
-    _document = document;
 }
 
 /**
@@ -79,22 +63,29 @@ void NavigationWidget::onItemClicked(QTreeWidgetItem *current, int column) {
 /**
  * Parses a text document and builds the navigation tree for it
  */
-void NavigationWidget::parse(const QTextDocument *document) {
+void NavigationWidget::parse(const QTextDocument *document, int textCursorPosition) {
     const QSignalBlocker blocker(this);
     Q_UNUSED(blocker)
 
-    setDocument(document);
+    _doc = document;
+    _cursorPosition = textCursorPosition;
+    doParse();
+}
 
-    const QFuture<QVector<Node>> future =
-        QtConcurrent::run(&NavigationWidget::parseDocument, document);
-    this->_parseFutureWatcher->setFuture(future);
+void NavigationWidget::doParse()
+{
+    const auto nodes = parseDocument(_doc);
+    buildNavTree(nodes);
 }
 
 QVector<Node> NavigationWidget::parseDocument(
     const QTextDocument *const document) {
     QVector<Node> nodes;
     for (int i = 0; i < document->blockCount(); ++i) {
-        const QTextBlock &block = document->findBlockByNumber(i);
+        const QTextBlock block = document->findBlockByNumber(i);
+        if (!block.isValid()) {
+            continue;
+        }
         const int elementType = block.userState();
 
         // ignore all non headline types
@@ -114,9 +105,37 @@ QVector<Node> NavigationWidget::parseDocument(
     return nodes;
 }
 
-void NavigationWidget::onParseCompleted() {
-    QVector<Node> nodes = this->_parseFutureWatcher->result();
-    if (_navigationTreeNodes == nodes) return;
+void NavigationWidget::selectItemForCursorPosition(int position)
+{
+    int itemIndex = findItemIndexforCursorPosition(position);
+
+    QTreeWidgetItem *itemToSelect{nullptr};
+    if (itemIndex >= 0) {
+        QTreeWidgetItemIterator it(this);
+        it += itemIndex;
+        itemToSelect = *it;
+    }
+
+    QSignalBlocker b(this);
+    setCurrentItem(itemToSelect);
+}
+
+
+int NavigationWidget::findItemIndexforCursorPosition(int position) const
+{
+    auto fwdIt = std::lower_bound(_navigationTreeNodes.begin(),
+                                  _navigationTreeNodes.end(),
+                                  position,
+                                  [](const Node &node, int position){return node.pos <= position;});
+
+    return fwdIt - std::begin(_navigationTreeNodes) - 1;
+}
+
+void NavigationWidget::buildNavTree(const QVector<Node> &nodes) {
+
+    if (_navigationTreeNodes == nodes)
+        return;
+
     _navigationTreeNodes = std::move(nodes);
 
     clear();
@@ -149,6 +168,7 @@ void NavigationWidget::onParseCompleted() {
         _lastHeadingItemList[elementType] = item;
     }
     expandAll();
+    selectItemForCursorPosition(_cursorPosition);
 }
 
 /**
