@@ -8,9 +8,9 @@
 class TodoItemTreeWidget : public QTreeWidget {
     Q_OBJECT
    public:
-    explicit TodoItemTreeWidget(QWidget *parent = Q_NULLPTR);
+    explicit TodoItemTreeWidget(QWidget *parent = nullptr);
    protected:
-    void dropEvent(QDropEvent *e);
+    void dropEvent(QDropEvent *e) override;
 
    Q_SIGNALS:
     void calendarItemUpdated(CalendarItem item);
